KENZY.Ai · |GitHub license| |Python Versions| |Read the Docs| |GitHub release (latest by date)|
===============================================================================================

This project is dedicated to building a “Synthetic Human” which is
called Kenzy for which we have assigned the female gender pronoun of
“she”. She has visual face recognition
(`opencv/opencv <https://github.com/opencv/opencv>`__), speech
transcription (`coqui <https://github.com/coqui-ai>`__), and speech
synthesis (`festival <http://www.cstr.ed.ac.uk/projects/festival/>`__ or
`mimic3 <https://github.com/MycroftAI/mimic3>`__). Kenzy is written in
Python and is targeted primarily at the single board computer (SBC)
platforms like the `Raspberry Pi <https://www.raspberrypi.org/>`__.

Visit our main site: https://kenzy.ai/

--------------

Help & Documentation

Help and additional details are available at https://docs.kenzy.ai/

.. |GitHub license| image:: https://img.shields.io/github/license/lnxusr1/kenzy
   :target: https://github.com/lnxusr1/kenzy/blob/master/LICENSE
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/yt2mp3.svg
.. |Read the Docs| image:: https://img.shields.io/readthedocs/kenzy
.. |GitHub release (latest by date)| image:: https://img.shields.io/github/v/release/lnxusr1/kenzy
